import React from 'react';
import { useOutlet } from 'react-router-dom';
import { PageWithHeader, Content, ContentHeader, CreateButton } from '@backstage/core-components';
import { useApi, configApiRef, useRouteRef } from '@backstage/core-plugin-api';
import { CatalogTable } from '@veecode-platform/plugin-catalog';
import { EntityListProvider, CatalogFilterLayout, EntityKindPicker, EntityTypePicker, UserListPicker, EntityOwnerPicker, EntityLifecyclePicker, EntityTagPicker } from '@backstage/plugin-catalog-react';
import { b as registerComponentRouteRef } from './ApiDefinitionWidget-798ee85f.esm.js';
import { usePermission } from '@backstage/plugin-permission-react';
import { adminAccessPermission } from '@veecode-platform/plugin-application-common';
import { catalogEntityCreatePermission } from '@backstage/plugin-catalog-common/alpha';

const defaultColumns = [
  CatalogTable.columns.createTitleColumn({ hidden: true }),
  CatalogTable.columns.createNameColumn({ defaultKind: "API" }),
  // CatalogTable.columns.createSystemColumn(),
  CatalogTable.columns.createOwnerColumn(),
  CatalogTable.columns.createSpecTypeColumn(),
  CatalogTable.columns.createSpecLifecycleColumn(),
  CatalogTable.columns.createPublishedAtColumn(),
  // CatalogTable.columns.createMetadataDescriptionColumn(),
  CatalogTable.columns.createTagsColumn()
];
const DefaultApiExplorerPage = (props) => {
  var _a;
  const { initiallySelectedFilter = "all", columns, actions } = props;
  const configApi = useApi(configApiRef);
  const generatedSubtitle = `${(_a = configApi.getOptionalString("organization.name")) != null ? _a : "Backstage"} API Explorer`;
  const registerComponentLink = useRouteRef(registerComponentRouteRef);
  const { loading: loadingPermission, allowed: adminView } = usePermission({
    permission: adminAccessPermission
  });
  usePermission({
    permission: catalogEntityCreatePermission
  });
  return /* @__PURE__ */ React.createElement(
    PageWithHeader,
    {
      themeId: "apis",
      title: "APIs",
      subtitle: generatedSubtitle,
      pageTitleOverride: "APIs"
    },
    /* @__PURE__ */ React.createElement(Content, null, /* @__PURE__ */ React.createElement(ContentHeader, { title: "" }, adminView && !loadingPermission && /* @__PURE__ */ React.createElement(
      CreateButton,
      {
        title: "Register Existing API",
        to: registerComponentLink == null ? void 0 : registerComponentLink()
      }
    )), /* @__PURE__ */ React.createElement(EntityListProvider, null, /* @__PURE__ */ React.createElement(CatalogFilterLayout, null, /* @__PURE__ */ React.createElement(CatalogFilterLayout.Filters, null, /* @__PURE__ */ React.createElement(EntityKindPicker, { initialFilter: "api", hidden: true }), /* @__PURE__ */ React.createElement(EntityTypePicker, null), /* @__PURE__ */ React.createElement(UserListPicker, { initialFilter: initiallySelectedFilter }), /* @__PURE__ */ React.createElement(EntityOwnerPicker, null), /* @__PURE__ */ React.createElement(EntityLifecyclePicker, null), /* @__PURE__ */ React.createElement(EntityTagPicker, null)), /* @__PURE__ */ React.createElement(CatalogFilterLayout.Content, null, /* @__PURE__ */ React.createElement(
      CatalogTable,
      {
        columns: columns || defaultColumns,
        actions
      }
    )))))
  );
};

const ApiExplorerPage = (props) => {
  const outlet = useOutlet();
  return outlet || /* @__PURE__ */ React.createElement(DefaultApiExplorerPage, { ...props });
};

export { ApiExplorerPage as A, DefaultApiExplorerPage as D };
//# sourceMappingURL=ApiExplorerPage-9618a213.esm.js.map
